( cd usr/lib ; rm -rf java )
( cd usr/lib ; ln -sf jre1.5.0_04 java )
( cd usr/lib/jre1.5.0_04/lib/i386/client ; rm -rf libjsig.so )
( cd usr/lib/jre1.5.0_04/lib/i386/client ; ln -sf ../libjsig.so libjsig.so )
( cd usr/lib/jre1.5.0_04/lib/i386/server ; rm -rf libjsig.so )
( cd usr/lib/jre1.5.0_04/lib/i386/server ; ln -sf ../libjsig.so libjsig.so )
( cd usr/lib/jre1.5.0_04/man ; rm -rf ja )
( cd usr/lib/jre1.5.0_04/man ; ln -sf ja_JP.eucJP ja )
( cd usr/lib/jre1.5.0_04/javaws ; rm -rf javaws )
( cd usr/lib/jre1.5.0_04/javaws ; ln -sf ../bin/javaws javaws )
( cd usr/lib/mozilla/plugins ; rm -rf libjavaplugin_oji.so )
( cd usr/lib/mozilla/plugins ; ln -sf /usr/lib/java/plugin/i386/ns7/libjavaplugin_oji.so libjavaplugin_oji.so )
